==> compass-2.1.0-sources.jar: org/compass/core/converter/basic/atomic/AtomicBooleanConverter.java <==
/*
 * Copyright 2004-2006 the original author or authors.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.compass.core.converter.basic.atomic;

import java.util.concurrent.atomic.AtomicBoolean;

import org.compass.core.Property;
import org.compass.core.converter.ConversionException;
import org.compass.core.converter.basic.AbstractBasicConverter;
import org.compass.core.mapping.ResourcePropertyMapping;
import org.compass.core.marshall.MarshallingContext;

/**
 * @author kimchy
 */
public class AtomicBooleanConverter extends AbstractBasicConverter {

    protected Object doFromString(String str, ResourcePropertyMapping resourcePropertyMapping, MarshallingContext context) throws ConversionException {
        return str.equals("true") ? new AtomicBoolean(true) : new AtomicBoolean(false);
    }

    /**
     * Boolean is {@link org.compass.core.Property.Index#NOT_ANALYZED} by default.
     */
    public Property.Index suggestIndex() {
        return Property.Index.NOT_ANALYZED;
    }
}

==> compass-2.2.0-sources.jar: org/compass/core/converter/basic/atomic/AtomicBooleanConverter.java <==
/*
 * Copyright 2004-2009 the original author or authors.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.compass.core.converter.basic.atomic;

import java.util.concurrent.atomic.AtomicBoolean;

import org.compass.core.Property;
import org.compass.core.converter.ConversionException;
import org.compass.core.converter.basic.AbstractBasicConverter;
import org.compass.core.mapping.ResourcePropertyMapping;
import org.compass.core.marshall.MarshallingContext;

/**
 * @author kimchy
 */
public class AtomicBooleanConverter extends AbstractBasicConverter<AtomicBoolean> {

    protected AtomicBoolean doFromString(String str, ResourcePropertyMapping resourcePropertyMapping, MarshallingContext context) throws ConversionException {
        return str.equals("true") ? new AtomicBoolean(true) : new AtomicBoolean(false);
    }

    /**
     * Boolean is {@link org.compass.core.Property.Index#NOT_ANALYZED} by default.
     */
    public Property.Index suggestIndex() {
        return Property.Index.NOT_ANALYZED;
    }
}
